==> examples_sjs1_3-0.1.0-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html#","e":false,"i":"","n":"examples","t":"examples","d":"","k":"static","x":""},
{"l":"chartreuse/examples.html#","e":false,"i":"","n":"chartreuse.examples","t":"chartreuse.examples","d":"","k":"package","x":""},
{"l":"chartreuse/examples/Annotations$.html#","e":false,"i":"","n":"Annotations","t":"Annotations","d":"chartreuse.examples","k":"object","x":""},
{"l":"chartreuse/examples/Annotations$.html#annotation-0","e":false,"i":"","n":"annotation","t":"annotation: Annotation","d":"chartreuse.examples.Annotations","k":"val","x":""},
{"l":"chartreuse/examples/Annotations$.html#chargeData-0","e":false,"i":"","n":"chargeData","t":"chargeData: ArraySeq[Point]","d":"chartreuse.examples.Annotations","k":"val","x":""},
{"l":"chartreuse/examples/Annotations$.html#drawDefault-571","e":false,"i":"","n":"drawDefault","t":"drawDefault(id: String): Unit","d":"chartreuse.examples.Annotations","k":"def","x":""},
{"l":"chartreuse/examples/Annotations$.html#drawWithPositioning-571","e":false,"i":"","n":"drawWithPositioning","t":"drawWithPositioning(id: String): Unit","d":"chartreuse.examples.Annotations","k":"def","x":""},
{"l":"chartreuse/examples/Annotations$.html#drawWithPositioningAndArrow-571","e":false,"i":"","n":"drawWithPositioningAndArrow","t":"drawWithPositioningAndArrow(id: String): Unit","d":"chartreuse.examples.Annotations","k":"def","x":""},
{"l":"chartreuse/examples/Annotations$.html#error-0","e":false,"i":"","n":"error","t":"error: Point","d":"chartreuse.examples.Annotations","k":"val","x":""},
{"l":"chartreuse/examples/Annotations$.html#plot-0","e":false,"i":"","n":"plot","t":"plot: Plot[Style & Layout & Shape]","d":"chartreuse.examples.Annotations","k":"val","x":""},
{"l":"chartreuse/examples/Annotations$.html#scatter-0","e":false,"i":"","n":"scatter","t":"scatter: Scatter[Point, Shape & Style]","d":"chartreuse.examples.Annotations","k":"val","x":""},
{"l":"chartreuse/examples/Annotations$.html#xData-0","e":false,"i":"","n":"xData","t":"xData: ArraySeq[String]","d":"chartreuse.examples.Annotations","k":"val","x":""},
{"l":"chartreuse/examples/Annotations$.html#yData-0","e":false,"i":"","n":"yData","t":"yData: ArraySeq[String]","d":"chartreuse.examples.Annotations","k":"val","x":""},
{"l":"chartreuse/examples/BahamasPopulation$.html#","e":false,"i":"","n":"BahamasPopulation","t":"BahamasPopulation","d":"chartreuse.examples","k":"object","x":""},
{"l":"chartreuse/examples/BahamasPopulation$.html#curve-0","e":false,"i":"","n":"curve","t":"curve: Curve[Point, Style & Path]","d":"chartreuse.examples.BahamasPopulation","k":"val","x":""},
{"l":"chartreuse/examples/BahamasPopulation$.html#draw-571","e":false,"i":"","n":"draw","t":"draw(id: String): Unit","d":"chartreuse.examples.BahamasPopulation","k":"def","x":""},
{"l":"chartreuse/examples/BahamasPopulation$.html#line-0","e":false,"i":"","n":"line","t":"line: Line[Point, Shape & Style & Path]","d":"chartreuse.examples.BahamasPopulation","k":"val","x":""},
{"l":"chartreuse/examples/BahamasPopulation$.html#plot-0","e":false,"i":"","n":"plot","t":"plot: Plot[Shape & Style & Path]","d":"chartreuse.examples.BahamasPopulation","k":"val","x":""},
{"l":"chartreuse/examples/BahamasPopulation$.html#population-0","e":false,"i":"","n":"population","t":"population: ArraySeq[Point]","d":"chartreuse.examples.BahamasPopulation","k":"val","x":""},
{"l":"chartreuse/examples/Examples$.html#","e":false,"i":"","n":"Examples","t":"Examples","d":"chartreuse.examples","k":"object","x":""},
{"l":"chartreuse/examples/Examples$.html#go-94c","e":false,"i":"","n":"go","t":"go(): Unit","d":"chartreuse.examples.Examples","k":"def","x":""},
{"l":"chartreuse/examples/HadCrut5$.html#","e":false,"i":"","n":"HadCrut5","t":"HadCrut5","d":"chartreuse.examples","k":"object","x":""},
{"l":"chartreuse/examples/HadCrut5$.html#data-0","e":false,"i":"","n":"data","t":"data: ArraySeq[Record]","d":"chartreuse.examples.HadCrut5","k":"val","x":""},
{"l":"chartreuse/examples/HadCrut5$.html#dateRe-0","e":false,"i":"","n":"dateRe","t":"dateRe: Regex","d":"chartreuse.examples.HadCrut5","k":"val","x":""},
{"l":"chartreuse/examples/HadCrut5$.html#parse-114","e":false,"i":"","n":"parse","t":"parse(date: String, anomaly: Double, lower: Double, upper: Double): Record","d":"chartreuse.examples.HadCrut5","k":"def","x":""},
{"l":"chartreuse/examples/HadCrut5$$Record.html#","e":false,"i":"","n":"Record","t":"Record(year: Int, month: Int, anomaly: Double, lower: Double, upper: Double)","d":"chartreuse.examples.HadCrut5","k":"class","x":""},
{"l":"chartreuse/examples/PlotExample$.html#","e":false,"i":"","n":"PlotExample","t":"PlotExample","d":"chartreuse.examples","k":"object","x":""},
{"l":"chartreuse/examples/PlotExample$.html#draw-571","e":false,"i":"","n":"draw","t":"draw(id: String): Unit","d":"chartreuse.examples.PlotExample","k":"def","x":""},
{"l":"chartreuse/examples/PlotExample$.html#drawBase16DefaultLight-571","e":false,"i":"","n":"drawBase16DefaultLight","t":"drawBase16DefaultLight(id: String): Unit","d":"chartreuse.examples.PlotExample","k":"def","x":""},
{"l":"chartreuse/examples/PlotExample$.html#drawBase16Ocean-571","e":false,"i":"","n":"drawBase16Ocean","t":"drawBase16Ocean(id: String): Unit","d":"chartreuse.examples.PlotExample","k":"def","x":""},
{"l":"chartreuse/examples/PlotExample$.html#drawBmh-571","e":false,"i":"","n":"drawBmh","t":"drawBmh(id: String): Unit","d":"chartreuse.examples.PlotExample","k":"def","x":""},
{"l":"chartreuse/examples/PlotExample$.html#drawDefault-571","e":false,"i":"","n":"drawDefault","t":"drawDefault(id: String): Unit","d":"chartreuse.examples.PlotExample","k":"def","x":""},
{"l":"chartreuse/examples/PlotExample$.html#drawFiveThirtyEight-571","e":false,"i":"","n":"drawFiveThirtyEight","t":"drawFiveThirtyEight(id: String): Unit","d":"chartreuse.examples.PlotExample","k":"def","x":""},
{"l":"chartreuse/examples/PlotExample$.html#plot-0","e":false,"i":"","n":"plot","t":"plot: Plot[Basic]","d":"chartreuse.examples.PlotExample","k":"val","x":""},
{"l":"chartreuse/examples/PlotExample$.html#randomLayer-0","e":false,"i":"","n":"randomLayer","t":"randomLayer: Layer[Point, Basic]","d":"chartreuse.examples.PlotExample","k":"def","x":""},
{"l":"chartreuse/examples/QuickStartExample$.html#","e":false,"i":"","n":"QuickStartExample","t":"QuickStartExample","d":"chartreuse.examples","k":"object","x":""},
{"l":"chartreuse/examples/QuickStartExample$.html#data-0","e":false,"i":"","n":"data","t":"data: List[Point]","d":"chartreuse.examples.QuickStartExample","k":"val","x":""},
{"l":"chartreuse/examples/QuickStartExample$.html#draw-571","e":false,"i":"","n":"draw","t":"draw(id: String): Unit","d":"chartreuse.examples.QuickStartExample","k":"def","x":""},
{"l":"chartreuse/examples/QuickStartExample$.html#layout-0","e":false,"i":"","n":"layout","t":"layout: Scatter[Point, Shape & Style]","d":"chartreuse.examples.QuickStartExample","k":"val","x":""},
{"l":"chartreuse/examples/QuickStartExample$.html#plot-0","e":false,"i":"","n":"plot","t":"plot: Plot[Style & Layout & Shape]","d":"chartreuse.examples.QuickStartExample","k":"val","x":""},
{"l":"chartreuse/examples/TemperatureAnomaly$.html#","e":false,"i":"","n":"TemperatureAnomaly","t":"TemperatureAnomaly","d":"chartreuse.examples","k":"object","x":""},
{"l":"chartreuse/examples/TemperatureAnomaly$.html#dataByYear-0","e":false,"i":"","n":"dataByYear","t":"dataByYear: Map[Int, ArraySeq[Record]]","d":"chartreuse.examples.TemperatureAnomaly","k":"val","x":""},
{"l":"chartreuse/examples/TemperatureAnomaly$.html#draw-571","e":false,"i":"","n":"draw","t":"draw(id: String): Unit","d":"chartreuse.examples.TemperatureAnomaly","k":"def","x":""},
{"l":"chartreuse/examples/TemperatureAnomaly$.html#layers-0","e":false,"i":"","n":"layers","t":"layers: List[Layer[Record, Shape & Style & Path]]","d":"chartreuse.examples.TemperatureAnomaly","k":"val","x":""},
{"l":"chartreuse/examples/TemperatureAnomaly$.html#plot-0","e":false,"i":"","n":"plot","t":"plot: Plot[Shape & Style & Path]","d":"chartreuse.examples.TemperatureAnomaly","k":"val","x":""}];

==> examples_sjs1_3-0.2.0-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html#","e":false,"i":"","n":"examples","t":"examples","d":"","k":"static","x":""},
{"l":"chartreuse/examples.html#","e":false,"i":"","n":"chartreuse.examples","t":"chartreuse.examples","d":"","k":"package","x":""},
{"l":"chartreuse/examples/Annotations$.html#","e":false,"i":"","n":"Annotations","t":"Annotations","d":"chartreuse.examples","k":"object","x":""},
{"l":"chartreuse/examples/Annotations$.html#annotation-0","e":false,"i":"","n":"annotation","t":"annotation: Annotation","d":"chartreuse.examples.Annotations","k":"val","x":""},
{"l":"chartreuse/examples/Annotations$.html#chargeData-0","e":false,"i":"","n":"chargeData","t":"chargeData: ArraySeq[Point]","d":"chartreuse.examples.Annotations","k":"val","x":""},
{"l":"chartreuse/examples/Annotations$.html#drawDefault-571","e":false,"i":"","n":"drawDefault","t":"drawDefault(id: String): Unit","d":"chartreuse.examples.Annotations","k":"def","x":""},
{"l":"chartreuse/examples/Annotations$.html#drawWithPositioning-571","e":false,"i":"","n":"drawWithPositioning","t":"drawWithPositioning(id: String): Unit","d":"chartreuse.examples.Annotations","k":"def","x":""},
{"l":"chartreuse/examples/Annotations$.html#drawWithPositioningAndArrow-571","e":false,"i":"","n":"drawWithPositioningAndArrow","t":"drawWithPositioningAndArrow(id: String): Unit","d":"chartreuse.examples.Annotations","k":"def","x":""},
{"l":"chartreuse/examples/Annotations$.html#error-0","e":false,"i":"","n":"error","t":"error: Point","d":"chartreuse.examples.Annotations","k":"val","x":""},
{"l":"chartreuse/examples/Annotations$.html#plot-0","e":false,"i":"","n":"plot","t":"plot: Plot[Style & Layout & Shape]","d":"chartreuse.examples.Annotations","k":"val","x":""},
{"l":"chartreuse/examples/Annotations$.html#scatter-0","e":false,"i":"","n":"scatter","t":"scatter: Scatter[Point, Shape & Style]","d":"chartreuse.examples.Annotations","k":"val","x":""},
{"l":"chartreuse/examples/Annotations$.html#xData-0","e":false,"i":"","n":"xData","t":"xData: ArraySeq[String]","d":"chartreuse.examples.Annotations","k":"val","x":""},
{"l":"chartreuse/examples/Annotations$.html#yData-0","e":false,"i":"","n":"yData","t":"yData: ArraySeq[String]","d":"chartreuse.examples.Annotations","k":"val","x":""},
{"l":"chartreuse/examples/BahamasPopulation$.html#","e":false,"i":"","n":"BahamasPopulation","t":"BahamasPopulation","d":"chartreuse.examples","k":"object","x":""},
{"l":"chartreuse/examples/BahamasPopulation$.html#curve-0","e":false,"i":"","n":"curve","t":"curve: Curve[Point, Style & Path]","d":"chartreuse.examples.BahamasPopulation","k":"val","x":""},
{"l":"chartreuse/examples/BahamasPopulation$.html#draw-571","e":false,"i":"","n":"draw","t":"draw(id: String): Unit","d":"chartreuse.examples.BahamasPopulation","k":"def","x":""},
{"l":"chartreuse/examples/BahamasPopulation$.html#line-0","e":false,"i":"","n":"line","t":"line: Line[Point, Shape & Style & Path]","d":"chartreuse.examples.BahamasPopulation","k":"val","x":""},
{"l":"chartreuse/examples/BahamasPopulation$.html#plot-0","e":false,"i":"","n":"plot","t":"plot: Plot[Shape & Style & Path]","d":"chartreuse.examples.BahamasPopulation","k":"val","x":""},
{"l":"chartreuse/examples/BahamasPopulation$.html#population-0","e":false,"i":"","n":"population","t":"population: ArraySeq[Point]","d":"chartreuse.examples.BahamasPopulation","k":"val","x":""},
{"l":"chartreuse/examples/Examples$.html#","e":false,"i":"","n":"Examples","t":"Examples","d":"chartreuse.examples","k":"object","x":""},
{"l":"chartreuse/examples/Examples$.html#go-94c","e":false,"i":"","n":"go","t":"go(): Unit","d":"chartreuse.examples.Examples","k":"def","x":""},
{"l":"chartreuse/examples/HadCrut5$.html#","e":false,"i":"","n":"HadCrut5","t":"HadCrut5","d":"chartreuse.examples","k":"object","x":""},
{"l":"chartreuse/examples/HadCrut5$.html#data-0","e":false,"i":"","n":"data","t":"data: ArraySeq[Record]","d":"chartreuse.examples.HadCrut5","k":"val","x":""},
{"l":"chartreuse/examples/HadCrut5$.html#dateRe-0","e":false,"i":"","n":"dateRe","t":"dateRe: Regex","d":"chartreuse.examples.HadCrut5","k":"val","x":""},
{"l":"chartreuse/examples/HadCrut5$.html#parse-114","e":false,"i":"","n":"parse","t":"parse(date: String, anomaly: Double, lower: Double, upper: Double): Record","d":"chartreuse.examples.HadCrut5","k":"def","x":""},
{"l":"chartreuse/examples/HadCrut5$$Record.html#","e":false,"i":"","n":"Record","t":"Record(year: Int, month: Int, anomaly: Double, lower: Double, upper: Double)","d":"chartreuse.examples.HadCrut5","k":"class","x":""},
{"l":"chartreuse/examples/PlotExample$.html#","e":false,"i":"","n":"PlotExample","t":"PlotExample","d":"chartreuse.examples","k":"object","x":""},
{"l":"chartreuse/examples/PlotExample$.html#draw-571","e":false,"i":"","n":"draw","t":"draw(id: String): Unit","d":"chartreuse.examples.PlotExample","k":"def","x":""},
{"l":"chartreuse/examples/PlotExample$.html#drawBase16DefaultLight-571","e":false,"i":"","n":"drawBase16DefaultLight","t":"drawBase16DefaultLight(id: String): Unit","d":"chartreuse.examples.PlotExample","k":"def","x":""},
{"l":"chartreuse/examples/PlotExample$.html#drawBase16Ocean-571","e":false,"i":"","n":"drawBase16Ocean","t":"drawBase16Ocean(id: String): Unit","d":"chartreuse.examples.PlotExample","k":"def","x":""},
{"l":"chartreuse/examples/PlotExample$.html#drawBmh-571","e":false,"i":"","n":"drawBmh","t":"drawBmh(id: String): Unit","d":"chartreuse.examples.PlotExample","k":"def","x":""},
{"l":"chartreuse/examples/PlotExample$.html#drawDefault-571","e":false,"i":"","n":"drawDefault","t":"drawDefault(id: String): Unit","d":"chartreuse.examples.PlotExample","k":"def","x":""},
{"l":"chartreuse/examples/PlotExample$.html#drawFiveThirtyEight-571","e":false,"i":"","n":"drawFiveThirtyEight","t":"drawFiveThirtyEight(id: String): Unit","d":"chartreuse.examples.PlotExample","k":"def","x":""},
{"l":"chartreuse/examples/PlotExample$.html#plot-0","e":false,"i":"","n":"plot","t":"plot: Plot[Basic]","d":"chartreuse.examples.PlotExample","k":"val","x":""},
{"l":"chartreuse/examples/PlotExample$.html#randomLayer-0","e":false,"i":"","n":"randomLayer","t":"randomLayer: Layer[Point, Basic]","d":"chartreuse.examples.PlotExample","k":"def","x":""},
{"l":"chartreuse/examples/QuickStartExample$.html#","e":false,"i":"","n":"QuickStartExample","t":"QuickStartExample","d":"chartreuse.examples","k":"object","x":""},
{"l":"chartreuse/examples/QuickStartExample$.html#data-0","e":false,"i":"","n":"data","t":"data: List[Point]","d":"chartreuse.examples.QuickStartExample","k":"val","x":""},
{"l":"chartreuse/examples/QuickStartExample$.html#draw-571","e":false,"i":"","n":"draw","t":"draw(id: String): Unit","d":"chartreuse.examples.QuickStartExample","k":"def","x":""},
{"l":"chartreuse/examples/QuickStartExample$.html#layout-0","e":false,"i":"","n":"layout","t":"layout: Scatter[Point, Shape & Style]","d":"chartreuse.examples.QuickStartExample","k":"val","x":""},
{"l":"chartreuse/examples/QuickStartExample$.html#plot-0","e":false,"i":"","n":"plot","t":"plot: Plot[Style & Layout & Shape]","d":"chartreuse.examples.QuickStartExample","k":"val","x":""},
{"l":"chartreuse/examples/TemperatureAnomaly$.html#","e":false,"i":"","n":"TemperatureAnomaly","t":"TemperatureAnomaly","d":"chartreuse.examples","k":"object","x":""},
{"l":"chartreuse/examples/TemperatureAnomaly$.html#dataByYear-0","e":false,"i":"","n":"dataByYear","t":"dataByYear: Map[Int, ArraySeq[Record]]","d":"chartreuse.examples.TemperatureAnomaly","k":"val","x":""},
{"l":"chartreuse/examples/TemperatureAnomaly$.html#draw-571","e":false,"i":"","n":"draw","t":"draw(id: String): Unit","d":"chartreuse.examples.TemperatureAnomaly","k":"def","x":""},
{"l":"chartreuse/examples/TemperatureAnomaly$.html#layers-0","e":false,"i":"","n":"layers","t":"layers: NonEmptySeq[Layer[Record, Shape & Style & Path]]","d":"chartreuse.examples.TemperatureAnomaly","k":"val","x":""},
{"l":"chartreuse/examples/TemperatureAnomaly$.html#plot-0","e":false,"i":"","n":"plot","t":"plot: Plot[Shape & Style & Path]","d":"chartreuse.examples.TemperatureAnomaly","k":"val","x":""}];
